asr.relax
=========

.. automodule:: asr.relax

   
   
   .. rubric:: Functions

   
   .. autofunction:: BN_check
   .. autofunction:: is_relax_done
   .. autofunction:: log
   .. autofunction:: relax
   
   

   
   
   .. rubric:: Classes

   
   .. autoclass:: SpgAtoms
   .. autoclass:: myBFGS
   
   

   
   
   .. rubric:: Exceptions

   
   .. autoexception:: BrokenSymmetryError
   
   